tsseg.algorithms.eagglo package
===============================

Non-parametric hierarchical agglomerative algorithm based on alpha-th absolute moment
of pairwise Euclidean distances.

| **Type:** change point detection
| **Supervision:** fully unsupervised
| **Complexity:** O(n²)
| **Requires:** numba

**Implementation:** Adapted from aeon (itself a port of R ``ecp``). BSD 3-Clause.

**Reference:** Matteson & James (2014), JASA.

Submodules
----------

tsseg.algorithms.eagglo.detector module
---------------------------------------

.. automodule:: tsseg.algorithms.eagglo.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.eagglo
   :members:
   :show-inheritance:
   :undoc-members:
